@@ -46,7 +46,7 @@ def _finalize_inputs(table, data_config):
         if len(names) == 1 and data_config.preprocess_params[names[0]]['length'] is None:
             output['_' + k] = ak.to_numpy(ak.values_astype(table[names[0]], 'float32'))
         else:
-            output['_' + k] = ak.to_numpy(np.stack([ak.values_astype(table[n], 'float32') for n in names], axis=1))
+            output['_' + k] = ak.to_numpy(np.stack([ak.to_numpy(table[n]).astype('float32') for n in names], axis=1))
     # copy monitor variables
     for k in data_config.z_variables:
         if k not in output:
